@@ -1,6 +1,7 @@
 /*-
 * syslog-rs - a syslog client translated from libc to rust
 * Copyright (C) 2021  Aleksandr Morozov
+* Copyright (C) 2021  RELKOM s.r.o
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
@@ -58,14 +59,16 @@ unsafe impl Send for SyslogSocket{}
 impl SyslogSocket
 {
     /// Creates a default instance
-    pub(crate) fn none() -> Self
+    pub(crate) 
+    fn none() -> Self
     {
         return Self::None;
     }
 
     /// Returns the rawfd without passing the ownership ower the
     /// the unixsocket. Will panic if called on enum None.
-    pub(crate) fn get_raw_fd(&self) -> RawFd
+    pub(crate) 
+    fn get_raw_fd(&self) -> RawFd
     {
         match *self
         {
@@ -112,7 +115,8 @@ impl SyslogSocket
 
     /// Performs the connection to the syslog's server socket.
     /// Picks the socket automatically.
-    pub(crate) fn connect() -> SyRes<Self>
+    pub(crate) 
+    fn connect() -> SyRes<Self>
     {
         // open connection first
         let stream = Self::connect_internal()?;
@@ -158,7 +162,8 @@ impl SyslogSocket
     }
 
     /// Writes to the socket. Will panic if instance is enum None.
-    pub(crate) fn send(&mut self, msg: &[u8]) -> std::io::Result<usize>
+    pub(crate) 
+    fn send(&mut self, msg: &[u8]) -> std::io::Result<usize>
     {
         match *self
         {
@@ -174,7 +179,8 @@ impl SyslogSocket
     }
 
     /// Shutdowns the socket. Will panic if instance is enum None.
-    pub(crate) fn shutdown(&mut self)
+    pub(crate) 
+    fn shutdown(&mut self)
     {
         match *self
         {
@@ -189,7 +195,8 @@ impl SyslogSocket
     }
 
     /// Returns true is current instance of enum is None.
-    pub(crate) fn is_none(&self) -> bool
+    pub(crate) 
+    fn is_none(&self) -> bool
     {
         match self
         {
@@ -201,7 +208,8 @@ impl SyslogSocket
     }
 
     /// Returns true if stream was connected to privileged socket.
-    pub(crate) fn is_priv(&self) -> bool
+    pub(crate) 
+    fn is_priv(&self) -> bool
     {
         match self
         {
