@@ -1,6 +1,7 @@
 /*-
 * syslog-rs - a syslog client translated from libc to rust
 * Copyright (C) 2021  Aleksandr Morozov
+* Copyright (C) 2021  RELKOM s.r.o
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
@@ -42,6 +43,7 @@ use super::error::{SyRes};
 // https://docs.rs/tokio/1.6.1/tokio/net/struct.UnixDatagram.html#method.unbound
 // https://docs.rs/tokio/1.6.1/tokio/sync/struct.Mutex.html
 
+/// Internal structure with syslog setup
 struct SyslogInternal
 {
     /// A identification i.e program name, thread name
@@ -109,7 +111,8 @@ impl SyslogInternal
 
 impl SyslogInternal
 {
-    pub fn set_logmask(&mut self, logmask: i32) -> i32
+    pub(crate) 
+    fn set_logmask(&mut self, logmask: i32) -> i32
     {
         let oldmask = self.logmask;
 
@@ -121,7 +124,8 @@ impl SyslogInternal
         return oldmask;
     }
 
-    pub fn send_to_stderr(&self, msg: &mut [u8])
+    pub(crate)  
+    fn send_to_stderr(&self, msg: &mut [u8])
     {
         if self.logstat.intersects(LogStat::LOG_PERROR) == true
         {
@@ -130,7 +134,8 @@ impl SyslogInternal
         }
     }
 
-    pub fn is_logmasked(&self, pri: i32) -> bool
+    pub(crate) 
+    fn is_logmasked(&self, pri: i32) -> bool
     {
         if ((1 << (pri & LogMask::LOG_PRIMASK)) & self.logmask) == 0
         {
@@ -140,7 +145,8 @@ impl SyslogInternal
         return false;
     }
 
-    pub fn set_logtag<L: AsRef<str>>(&mut self, logtag: L)
+    pub(crate) 
+    fn set_logtag<L: AsRef<str>>(&mut self, logtag: L)
     {
         self.logtag = 
             Some(truncate_n(logtag.as_ref(), 48));
@@ -174,7 +180,8 @@ impl SyslogInternal
     /// A glibc implementation RFC3164
     #[cfg(target_os = "linux")]
     #[async_recursion]
-    async fn vsyslog1(&mut self, mut pri: i32, fmt: &str)
+    async 
+    fn vsyslog1(&mut self, mut pri: i32, fmt: &str)
     {
         // check for invalid bits
         match check_invalid_bits(&mut pri)
@@ -266,7 +273,12 @@ impl SyslogInternal
         self.send_to_stderr(&mut msg);
         
         
-        let fullmsg = [msg_pri.as_slice(), msg_header.as_slice(), msg.as_slice()].concat();
+        let fullmsg = 
+            [
+                msg_pri.as_slice(), 
+                msg_header.as_slice(), 
+                msg.as_slice()
+            ].concat();
 
         if self.stream.is_none() == true
         {
@@ -276,7 +288,7 @@ impl SyslogInternal
                 Ok(_) => {},
                 Err(e) =>
                 {
-                    self.send_to_stderr(unsafe { e.eject_string().as_bytes_mut() } );
+                    self.send_to_stderr(unsafe { e.into_inner().as_bytes_mut() } );
                     return;
                 }
             }
@@ -358,7 +370,8 @@ impl SyslogInternal
         target_os = "macos"
     ))]
     #[async_recursion]
-    async fn vsyslog1(&mut self, mut pri: i32, fmt: &str)
+    async 
+    fn vsyslog1(&mut self, mut pri: i32, fmt: &str)
     {
         // check for invalid bits
         match check_invalid_bits(&mut pri)
@@ -453,7 +466,12 @@ impl SyslogInternal
         self.send_to_stderr(&mut msg);
         
         
-        let fullmsg = [msg_pri.as_slice(), msg_header.as_slice(), msg.as_slice()].concat();
+        let fullmsg = 
+            [
+                msg_pri.as_slice(), 
+                msg_header.as_slice(), 
+                msg.as_slice()
+            ].concat();
 
         if self.stream.is_none() == true
         {
@@ -579,10 +597,12 @@ impl Syslog
     ///         LogStat::LOG_NDELAY | LogStat::LOG_PID, 
     ///         LogFacility::LOG_DAEMON);
     /// ```
-    pub async fn openlog(
+    pub async 
+    fn openlog(
         ident: Option<&str>, 
         logstat: LogStat, 
-        facility: LogFacility) -> SyRes<Self>
+        facility: LogFacility
+    ) -> SyRes<Self>
     {
 
         let inner = 
@@ -614,7 +634,8 @@ impl Syslog
     ///
     /// ~(LOG_MASK!(Priority::LOG_INFO))
     /// LOG_UPTO!(Priority::LOG_ERROR)
-    pub async fn setlogmask(&self, logmask: i32) -> i32
+    pub async 
+    fn setlogmask(&self, logmask: i32) -> i32
     {
         //lock
         let mut lock = self.lock.lock().await;
@@ -630,7 +651,8 @@ impl Syslog
     }
 
     /// Similar to libc, closelog() will close the log
-    pub async fn closelog(&self)
+    pub async 
+    fn closelog(&self)
     {
         //lock
         let mut lock = self.lock.lock().await;
@@ -650,7 +672,8 @@ impl Syslog
     /// * `fmt` - a string message. In C exists a functions with
     ///     variable argumets amount. In Rust you should create your
     ///     own macros like format!() or use format!()]
-    pub async fn syslog(&self, pri: Priority, fmt: String)
+    pub async 
+    fn syslog(&self, pri: Priority, fmt: String)
     {
         //self.vsyslog(pri, fmt).await;
         //lock
@@ -664,7 +687,8 @@ impl Syslog
     }
 
     /// Similar to syslog() and created for the compatability.
-    pub async fn vsyslog<S: AsRef<str>>(&self, pri: Priority, fmt: S)
+    pub async 
+    fn vsyslog<S: AsRef<str>>(&self, pri: Priority, fmt: S)
     {
         //lock
         let mut lock = self.lock.lock().await;
@@ -683,7 +707,8 @@ impl Syslog
     /// # Arguments
     /// 
     /// * `ident` - a new identity (up to 48 UTF8 chars)
-    pub async fn change_identity<I: AsRef<str>>(&self, ident: I)
+    pub async 
+    fn change_identity<I: AsRef<str>>(&self, ident: I)
     {
         //lock
         let mut lock = self.lock.lock().await;
