@@ -1,3 +1,23 @@
+/*-
+* syslog-rs - a syslog client translated from libc to rust
+* Copyright (C) 2021  Aleksandr Morozov
+* Copyright (C) 2021  RELKOM s.r.o
+* 
+* This program is free software; you can redistribute it and/or
+* modify it under the terms of the GNU Lesser General Public
+* License as published by the Free Software Foundation; either
+* version 3 of the License, or (at your option) any later version.
+*
+* This program is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+* Lesser General Public License for more details.
+* 
+* You should have received a copy of the GNU Lesser General Public License
+* along with this program; if not, write to the Free Software Foundation,
+* Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+*/
+
 use std::thread::sleep;
 use std::time::Duration;
 use std::cell::{Cell, RefCell};
@@ -83,7 +103,8 @@ impl SyncSyslogInternal
                 LogFacility::LOG_USER
             };
 
-        let ident = match ident
+        let ident = 
+            match ident
             {
                 Some(r) => Some(truncate_n(r, 48)),
                 None => None,
@@ -132,7 +153,8 @@ impl SyncSyslogInternal
         return oldmask;
     }
 
-    pub(crate) fn set_logtag<L: AsRef<str>>(&self, logtag: L)
+    pub(crate) 
+    fn set_logtag<L: AsRef<str>>(&self, logtag: L)
     {
         *self.logtag.borrow_mut() = 
             Some(truncate_n(logtag.as_ref(), 48));
@@ -140,7 +162,8 @@ impl SyncSyslogInternal
 
     /// Disconnects the unix stream from syslog.
     /// Should be called only when lock is acuired
-    pub(crate) fn disconnectlog(&self)
+    pub(crate) 
+    fn disconnectlog(&self)
     {
         if self.stream.borrow().is_none() == false
         {
@@ -153,7 +176,8 @@ impl SyncSyslogInternal
     /// Connects unix stream to the syslog and sets up the properties of
     /// the unix stream.
     /// Should be called only when lock is acuired
-    pub(crate) fn connectlog(&self) -> SyRes<()>
+    pub(crate) 
+    fn connectlog(&self) -> SyRes<()>
     {
         let stream = SyslogSocket::connect()?;
 
@@ -165,7 +189,8 @@ impl SyncSyslogInternal
     /// An internal function which is called by the syslog or vsyslog.
     /// A glibc implementation RFC3164
     #[cfg(target_os = "linux")]
-    pub(crate) fn vsyslog1<S: AsRef<str>>(&self, mut pri: i32, fmt: S)
+    pub(crate) 
+    fn vsyslog1<S: AsRef<str>>(&self, mut pri: i32, fmt: S)
     {
         // check for invalid bits
         match check_invalid_bits(&mut pri)
@@ -252,7 +277,12 @@ impl SyncSyslogInternal
         self.send_to_stderr(&mut msg);
         
         
-        let fullmsg = [msg_pri.as_slice(), msg_header.as_slice(), msg.as_slice()].concat();
+        let fullmsg = 
+            [
+                msg_pri.as_slice(), 
+                msg_header.as_slice(), 
+                msg.as_slice()
+            ].concat();
 
         if self.stream.borrow().is_none() == true
         {
@@ -262,7 +292,7 @@ impl SyncSyslogInternal
                 Ok(_) => {},
                 Err(e) =>
                 {
-                    self.send_to_stderr(unsafe { e.eject_string().as_bytes_mut() } );
+                    self.send_to_stderr(unsafe { e.into_inner().as_bytes_mut() } );
                     return;
                 }
             }
