@@ -18,7 +18,7 @@
 */
 
 /*#![feature(const_mut_refs)]
-#![feature(const_fn)]*/
+#![feature(const_fn)]*/ 
 
 /*
     This is unsafe realization of the Cell. Uses unsafe code.
@@ -80,7 +80,8 @@ impl<T: Send> UnsafeReadOnlyCell<T>
     ///         unsafe { UnsafeReadOnlyCell::new_uninitialized("a_label") };
     /// }
     /// ```
-    pub unsafe fn new_uninitialized(
+    pub unsafe 
+    fn new_uninitialized(
         title: &'static str
     ) -> UnsafeReadOnlyCell<T> 
     {
@@ -100,7 +101,8 @@ impl<T: Send> UnsafeReadOnlyCell<T>
     /// # Return
     /// 
     /// Nothing, but will panic on attempt to call this function again.
-    pub unsafe fn init(&self, init: T) 
+    pub unsafe 
+    fn init(&self, init: T) 
     {
         if self.blocked.load(Ordering::SeqCst) == false
         {
@@ -119,7 +121,8 @@ impl<T: Send> UnsafeReadOnlyCell<T>
     /// # Return
     ///
     /// True - is locked or false.
-    pub fn is_init(&self) -> bool
+    pub 
+    fn is_init(&self) -> bool
     {
         return self.blocked.load(Ordering::SeqCst);
     }
